@@ -462,7 +462,7 @@ def main(tests=None, testdir=None, verbose=0, quiet=False,
 
     test_times = []
     test_support.use_resources = use_resources
-    save_modules = sys.modules.keys()
+    save_modules = set(sys.modules)
 
     def accumulate_result(test, result):
         ok, test_time = result
@@ -1503,6 +1503,7 @@ _expectations['freebsd7'] = _expectations['freebsd4']
 _expectations['freebsd8'] = _expectations['freebsd4']
 _expectations['openbsd4'] = _expectations['openbsd3']
 _expectations['openbsd5'] = _expectations['openbsd3']
+_expectations['openbsd6'] = _expectations['openbsd3']
 
 class _ExpectedSkips:
     def __init__(self):
